@@ -4,6 +4,7 @@
 
 // [[Rcpp::depends(RcppParallel)]]
 #include <RcppParallel.h>
+
 // [[Rcpp::depends(RcppArmadillo)]]
 #include <RcppArmadillo.h>
 
@@ -11,26 +12,27 @@
 
 #include <memory>
 
-typedef tbb::concurrent_unordered_map<std::pair<int, int>, double> tbbUPMap;
-typedef tbb::concurrent_unordered_map<int, double> tbbUMap;
-
 // TODO: Representation of Results
 // column-wise, row-wise, or full
 #if RCPP_PARALLEL_USE_TBB
+#include "tbb/concurrent_unordered_map.h"
+typedef tbb::concurrent_unordered_map<std::pair<int, int>, double> tbbUPMap;
+typedef tbb::concurrent_unordered_map<int, double> tbbUMap;
+#endif
 
 struct parallelDistance : public RcppParallel::Worker {
   const arma::mat& input_;
   std::shared_ptr<distance> dist_;
   const std::size_t nrow_;
   arma::vec& output_;
-  
+
   parallelDistance(
     const arma::mat& input,
     const std::shared_ptr<distance> dist,
     const std::size_t nrow,
     arma::vec& output
   ) : input_(input), dist_(dist), nrow_(nrow), output_(output) {}
-  
+
   void operator() (std::size_t begin, std::size_t end) {
     for (std::size_t i=begin;i<end;++i) {
       for (std::size_t j=i+1;j<nrow_;++j) {
@@ -47,7 +49,7 @@ struct parallelDistanceNM : public RcppParallel::Worker {
   std::shared_ptr<distance> dist_;
   const int nrow_;
   arma::mat& output_;
-  
+
   parallelDistanceNM(
     const arma::mat& inputX,
     const arma::mat& inputY,
@@ -55,7 +57,7 @@ struct parallelDistanceNM : public RcppParallel::Worker {
     const int nrow,
     arma::mat& output
   ) : inputX_(inputX), inputY_(inputY), dist_(dist), nrow_(nrow), output_(output) {}
-  
+
   void operator() (std::size_t begin, std::size_t end) {
     std::size_t nrow2 = inputY_.n_rows;
     for (std::size_t i=begin;i<end;++i) {
@@ -72,23 +74,17 @@ struct parallelMatrixNorm : public RcppParallel::Worker {
   const arma::mat& inputY_;
   std::shared_ptr<distance> dist_;
   arma::vec& output_;
-  
+
   parallelMatrixNorm(
     const arma::mat& inputX,
     const arma::mat& inputY,
     const std::shared_ptr<distance> dist,
     arma::vec& output
   ) : inputX_(inputX), inputY_(inputY), dist_(dist), output_(output) {}
-  
+
   void operator() (std::size_t begin, std::size_t end) {
     for (std::size_t i=begin;i<end;++i) {
       output_(i) = dist_->calc_distance(inputX_.row(i), inputX_.row(i));
     }
   }
 };
-
-#else
-
-// no single threated implementation
-
-#endif
